#
# spec file for package clojure
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define         toolsver 447
Name:           clojure
Version:        1.10.1
Release:        bp153.1.11
Summary:        A dynamic programming language that targets the JVM
License:        EPL-1.0
Group:          Development/Languages/Other
URL:            http://clojure.org/
Source0:        https://download.clojure.org/install/clojure-tools-%{version}.%{toolsver}.tar.gz
Requires:       java >= 1.8.0
BuildRequires:  fdupes
BuildArch:      noarch

%description
Clojure is a dynamic programming language that targets the Java
Virtual Machine (and the CLR, and JavaScript). It is designed to be a
general-purpose language, combining the approachability and
interactive development of a scripting language with an
infrastructure for multithreaded programming. Clojure is a
compiled language - it compiles directly to JVM bytecode, yet remains
completely dynamic. Every feature supported by Clojure is supported at
runtime. Clojure provides access to the Java frameworks, with
optional type hints and type inference, to ensure that calls to Java
can avoid reflection.

%prep
%setup -q -n clojure-tools
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" clj
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" clojure
#sed -i "s|PREFIX|%{_prefix}|" clojure
sed -i "s|PREFIX|/usr/share/clojure|" clojure

%build

%install

install -Dm644 deps.edn "%{buildroot}/usr/share/clojure/deps.edn"
install -Dm644 example-deps.edn "%{buildroot}/usr/share/clojure/example-deps.edn"
install -Dm644 clojure-tools-%{version}.%{toolsver}.jar "%{buildroot}/usr/share/clojure/libexec/clojure-tools-%{version}.%{toolsver}.jar"
install -Dm755 clojure "%{buildroot}/usr/bin/clojure"
install -Dm755 clj "%{buildroot}/usr/bin/clj"
install -Dm644 clojure.1 "%{buildroot}/usr/share/man/man1/clojure.1"
install -Dm644 clj.1 "%{buildroot}/usr/share/man/man1/clj.1"

%fdupes %{buildroot}/%{_prefix}

%files
%dir %{_datadir}/clojure
%dir %{_datadir}/clojure/libexec
%{_bindir}/clj
%{_bindir}/clojure
%{_datadir}/clojure/deps.edn
%{_datadir}/clojure/example-deps.edn
%{_datadir}/clojure/libexec/clojure-tools-1.10.1.447.jar
%{_datadir}/man/man1/clj.1.gz
%{_datadir}/man/man1/clojure.1.gz

%changelog
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions.
- Use more macros in %%files.
* Tue Jul 23 2019 Dario Maiocchi <dmaiocchi@suse.com>
- update sed to use /bin/bash for setting up the shellbang
* Tue Jul 16 2019 mvetter@suse.com
- Use clojure-tools
- Drop custom clojure.1 and clojure
- Drop suse_version macros
* Tue Jul 16 2019 mvetter@suse.com
- Require java 1.8.0
* Tue Jul 16 2019 mvetter@suse.com
- Remove PKGBUILD. Not interested in Arch package in oS devel repo
* Tue Jul 16 2019 mvetter@suse.com
- Update to 0.10.1:
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md#changes-to-clojure-in-version-1101
- Upstream ships jar instead of zip now
- Remove files installed as doc because no zip file anymore
* Tue Jul 16 2019 mvetter@suse.com
- Cleanup spec file
* Tue Aug  2 2016 kkaempf@suse.com
- Update to 1.8.0
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md#changes-to-clojure-in-version-18
  + Direct linking
  + New string functions
  + Socket server and REPL
  + Enhancements
    + Error handling
    + Documentation strings
    + Performance
  + Bug fixes
* Sun Jul  5 2015 kgronlund@suse.com
- Update to 1.7.0
  + Changelog at https://github.com/clojure/clojure/blob/master/changes.md
  + Transducers
  + Reader Conditionals
  + Keyword and Symbol Construction
  + Warn on Boxed Math
  + update - like update-in for first level
  + Faster reduce and iterator paths
  + Printing as data
  + run!
* Fri Aug 29 2014 kgronlund@suse.com
- Update to 1.6.0
* Sun Jan 12 2014 kgronlund@suse.com
- Initial version.
